Introduction
============

``oedes`` (Open Electronic DEvice Simulator) is a Python software package for modeling of novel electronic devices based on new materials. It is applicable to organic electronic, electrochemical, bioelectronic, and Peroskvite based devices.

`oedes` was written to take into account both the special aspects of non-conventional electronic devices, and the modern trends in software development. The result a small but powerful package, which is tightly integrated with standard scientific software stack. This simplifies both running and sharing the simulations.

`oedes` development goals are to:

- enable `open science` research in novel electronic devices, by enabling full disclosure of numerical simulations;
- allow reuse of established device models, which were published without implementation;
- accelerate research by providing a platform for parameter extraction from measurements and for simulation based device optimization;
- simplify development of new simulation models and tools, by providing a library of basic components;
- provide a standard way of running and sharing device simulations.

`oedes` is released as open-source under GNU Affero General Public License v3. It is free to use and distributed with complete source code. 
